summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
author健美猫 <weijianwen@gmail.com>2018-05-03 23:08:48 +0800
committerAdam J. Stewart <ajstewart426@gmail.com>2018-05-03 10:08:48 -0500
commit05f51c46ddfcc0c854a49323bac234aa65051281 (patch)
tree95d1181bd5e162783ab4c3e279494a8dd6a8a3c0
parentfb9898230e39c973d5b570c0b146fa92fa46abd6 (diff)
downloadspack-05f51c46ddfcc0c854a49323bac234aa65051281.tar.gz
spack-05f51c46ddfcc0c854a49323bac234aa65051281.tar.bz2
spack-05f51c46ddfcc0c854a49323bac234aa65051281.tar.xz
spack-05f51c46ddfcc0c854a49323bac234aa65051281.zip
Bump gatk version to 4.0.4.0. (#7985)
* Bump gatk version to 4.0.4.0. * Update. * Fixed. * Fixed.
-rw-r--r--var/spack/repos/builtin/packages/gatk/package.py18
1 files changed, 13 insertions, 5 deletions
diff --git a/var/spack/repos/builtin/packages/gatk/package.py b/var/spack/repos/builtin/packages/gatk/package.py
index 8ac97bae8b..8ca12f133a 100644
--- a/var/spack/repos/builtin/packages/gatk/package.py
+++ b/var/spack/repos/builtin/packages/gatk/package.py
@@ -33,23 +33,31 @@ class Gatk(Package):
"""Genome Analysis Toolkit
Variant Discovery in High-Throughput Sequencing Data
"""
- homepage = "http://broadinstitute.github.io/gatk/"
- url = "https://software.broadinstitute.org/gatk/download/auth?package=GATK"
- _urlfmt = "https://github.com/broadgsa/gatk-protected/archive/{0}.tar.gz"
+ homepage = "https://software.broadinstitute.org/gatk/"
+ url = "https://github.com/broadinstitute/gatk/releases/download/4.0.4.0/gatk-4.0.4.0.zip"
+ version('4.0.4.0', '083d655883fb251e837eb2458141fc2b',
+ url="https://github.com/broadinstitute/gatk/releases/download/4.0.4.0/gatk-4.0.4.0.zip")
version('3.8-0', '0581308d2a25f10d11d3dfd0d6e4d28e', extension='tar.gz',
url="https://software.broadinstitute.org/gatk/download/auth?package=GATK")
depends_on('java@8:', type='run')
+ depends_on('python@2.6:2.8,3.6:', type='run', when='@4.0:')
+ depends_on('r@3.2:', type='run', when='@4.0:')
def install(self, spec, prefix):
mkdirp(prefix.bin)
# The list of files to install varies with release...
- # ... but skip the spack-{build.env}.out files.
- files = [x for x in glob.glob("*") if not re.match("^spack-", x)]
+ # ... but skip the spack-{build.env}.out files and gatkdoc directory.
+ files = [x for x in glob.glob("*")
+ if not re.match("^spack-", x) and not re.match("^gatkdoc", x)]
for f in files:
install(f, prefix.bin)
+ # Skip helper script settings
+ if spec.satisfies('@:4.0'):
+ return
+
# Set up a helper script to call java on the jar file,
# explicitly codes the path for java and the jar file.
script_sh = join_path(os.path.dirname(__file__), "gatk.sh")